# Drastically reduced YAML / JSON query

Tiny package providing a module with a part of
`yq` or `jq` functionality:

-   get a single value from a YAML or JSON file
-   change a single value in a YAML file


## Requirements

[PyYAML](https://pypi.org/project/PyYAML/)


## Installation

```
pip install dryjq
```

Installation in a virtual environment or with the `--user` option is recommended.


## Usage

_TODO_

## Issues, feature requests

Please open an issue [here](https://gitlab.com/blackstream-x/python-dryjq/-/issues)
if you found a bug or have a feature suggestion.

